SDL_mixer: api: Renamed `MIX_*Master*` to `MIX_*Mixer*`.

From 4b598e0fa723a5960790e30028fb527d2338e93b Mon Sep 17 00:00:00 2001
From: "Ryan C. Gordon" <[EMAIL REDACTED]>
Date: Fri, 16 Jan 2026 14:03:32 -0500
Subject: [PATCH] api: Renamed `MIX_*Master*` to `MIX_*Mixer*`.

These functions didn't follow the pattern of the rest of the API.

Fixes #802.
---
 docs/README-migration.md       |  4 ++--
 include/SDL3_mixer/SDL_mixer.h | 34 +++++++++++++++++-----------------
 src/SDL_mixer.c                |  8 ++++----
 src/SDL_mixer.exports          |  8 ++++----
 src/SDL_mixer.sym              |  8 ++++----
 5 files changed, 31 insertions(+), 31 deletions(-)

diff --git a/docs/README-migration.md b/docs/README-migration.md
index 5d4f8e1aa..ba76861e6 100644
--- a/docs/README-migration.md
+++ b/docs/README-migration.md
@@ -243,7 +243,7 @@ Mix_VolumeChunk() and Mix_VolumeMusic() are replaced by MIX_SetTrackGain(). They
 take a float instead of an int from 0 to 128, and can be used to not only quiet
 the existing data, but also make it louder.
 
-Mix_MasterVolume() is replaced by MIX_SetMasterGain(). Same idea.
+Mix_MasterVolume() is replaced by MIX_SetMixerGain(). Same idea.
 
 
 ## Halting
@@ -363,7 +363,7 @@ can discuss it!
 - Mix_VolumeChunk => MIX_SetTrackGain; gain is not set on MIX_Audio, only on MIX_Track
 - Mix_VolumeMusic => MIX_SetTrackGain
 - Mix_GetMusicVolume => MIX_GetTrackGain
-- Mix_MasterVolume => MIX_SetMasterGain
+- Mix_MasterVolume => MIX_SetMixerGain
 - Mix_HaltChannel => MIX_StopTrack
 - Mix_HaltGroup => MIX_StopTag
 - Mix_HaltMusic => MIX_StopTrack
diff --git a/src/SDL_mixer.c b/src/SDL_mixer.c
index 344028451..3f4ec3052 100644
--- a/src/SDL_mixer.c
+++ b/src/SDL_mixer.c
@@ -2522,7 +2522,7 @@ bool MIX_SetTrackStoppedCallback(MIX_Track *track, MIX_TrackStoppedCallback cb,
     return true;
 }
 
-bool MIX_SetMasterGain(MIX_Mixer *mixer, float gain)
+bool MIX_SetMixerGain(MIX_Mixer *mixer, float gain)
 {
     if (!CheckMixerParam(mixer)) {
         return false;
@@ -2536,7 +2536,7 @@ bool MIX_SetMasterGain(MIX_Mixer *mixer, float gain)
     return true;
 }
 
-float MIX_GetMasterGain(MIX_Mixer *mixer)
+float MIX_GetMixerGain(MIX_Mixer *mixer)
 {
     if (!CheckMixerParam(mixer)) {
         return 1.0f;
@@ -2613,7 +2613,7 @@ bool MIX_SetTagGain(MIX_Mixer *mixer, const char *tag, float gain)
     return true;
 }
 
-bool MIX_SetMasterFrequencyRatio(MIX_Mixer *mixer, float ratio)
+bool MIX_SetMixerFrequencyRatio(MIX_Mixer *mixer, float ratio)
 {
     if (!CheckMixerParam(mixer)) {
         return false;
@@ -2625,7 +2625,7 @@ bool MIX_SetMasterFrequencyRatio(MIX_Mixer *mixer, float ratio)
     return SDL_SetAudioStreamFrequencyRatio(mixer->output_stream, ratio);
 }
 
-float MIX_GetMasterFrequencyRatio(MIX_Mixer *mixer)
+float MIX_GetMixerFrequencyRatio(MIX_Mixer *mixer)
 {
     if (!CheckMixerParam(mixer)) {
         return 0.0f;
diff --git a/src/SDL_mixer.exports b/src/SDL_mixer.exports
index 500c568f4..9b8a7369f 100644
--- a/src/SDL_mixer.exports
+++ b/src/SDL_mixer.exports
@@ -47,8 +47,8 @@ _MIX_ResumeAllTracks
 _MIX_ResumeTag
 _MIX_TrackPlaying
 _MIX_TrackPaused
-_MIX_SetMasterGain
-_MIX_GetMasterGain
+_MIX_SetMixerGain
+_MIX_GetMixerGain
 _MIX_SetTrackGain
 _MIX_GetTrackGain
 _MIX_SetTagGain
@@ -88,6 +88,6 @@ _MIX_SetTrackLoops
 _MIX_GetTrackFadeFrames
 _MIX_GetTrackTags
 _MIX_GetTaggedTracks
-_MIX_SetMasterFrequencyRatio
-_MIX_GetMasterFrequencyRatio
+_MIX_SetMixerFrequencyRatio
+_MIX_GetMixerFrequencyRatio
 # extra symbols go here (don't modify this line)
diff --git a/src/SDL_mixer.sym b/src/SDL_mixer.sym
index 3f2229f4e..febfe92c4 100644
--- a/src/SDL_mixer.sym
+++ b/src/SDL_mixer.sym
@@ -48,8 +48,8 @@ SDL3_mixer_0.0.0 {
     MIX_ResumeTag;
     MIX_TrackPlaying;
     MIX_TrackPaused;
-    MIX_SetMasterGain;
-    MIX_GetMasterGain;
+    MIX_SetMixerGain;
+    MIX_GetMixerGain;
     MIX_SetTrackGain;
     MIX_GetTrackGain;
     MIX_SetTagGain;
@@ -89,8 +89,8 @@ SDL3_mixer_0.0.0 {
     MIX_GetTrackFadeFrames;
     MIX_GetTrackTags;
     MIX_GetTaggedTracks;
-    MIX_SetMasterFrequencyRatio;
-    MIX_GetMasterFrequencyRatio;
+    MIX_SetMixerFrequencyRatio;
+    MIX_GetMixerFrequencyRatio;
     # extra symbols go here (don't modify this line)
   local: *;
 };
diff --git a/include/SDL3_mixer/SDL_mixer.h b/include/SDL3_mixer/SDL_mixer.h
index f4a6c3e1d..b6a6e34ee 100644
--- a/include/SDL3_mixer/SDL_mixer.h
+++ b/include/SDL3_mixer/SDL_mixer.h
@@ -86,10 +86,10 @@
  *
  * This library offers several features on top of mixing sounds together: a
  * track can have its own gain, to adjust its volume, in addition to a master
- * gain applied as well. One can set the "frequency ratio" of a track, to
- * speed it up or slow it down, which also adjusts its pitch. A channel map
- * can also be applied per-track, to change what speaker a given channel of
- * audio is output to.
+ * gain applied as well. One can set the "frequency ratio" of a track or the
+ * final mixed output, to speed it up or slow it down, which also adjusts its
+ * pitch. A channel map can also be applied per-track, to change what speaker
+ * a given channel of audio is output to.
  *
  * Almost all timing in SDL_mixer is in _sample frames_. Stereo PCM audio data
  * in Sint16 format takes 4 bytes per sample frame (2 bytes per sample times 2
@@ -2157,15 +2157,15 @@ extern SDL_DECLSPEC bool SDLCALL MIX_TrackPaused(MIX_Track *track);
  *
  * \since This function is available since SDL_mixer 3.0.0.
  *
- * \sa MIX_GetMasterGain
+ * \sa MIX_GetMixerGain
  * \sa MIX_SetTrackGain
  */
-extern SDL_DECLSPEC bool SDLCALL MIX_SetMasterGain(MIX_Mixer *mixer, float gain);
+extern SDL_DECLSPEC bool SDLCALL MIX_SetMixerGain(MIX_Mixer *mixer, float gain);
 
 /**
  * Get a mixer's master gain control.
  *
  * This returns the last value set through MIX_SetMasterGain(), or 1.0f if no
  * value has ever been explicitly set.
  *
  * \param mixer the mixer to query.
@@ -2175,10 +2175,10 @@ extern SDL_DECLSPEC bool SDLCALL MIX_SetMasterGain(MIX_Mixer *mixer, float gain)
  *
  * \since This function is available since SDL_mixer 3.0.0.
  *
- * \sa MIX_SetMasterGain
+ * \sa MIX_SetMixerGain
  * \sa MIX_GetTrackGain
  */
-extern SDL_DECLSPEC float SDLCALL MIX_GetMasterGain(MIX_Mixer *mixer);
+extern SDL_DECLSPEC float SDLCALL MIX_GetMixerGain(MIX_Mixer *mixer);
 
 /**
  * Set a track's gain control.
@@ -2204,7 +2204,7 @@ extern SDL_DECLSPEC float SDLCALL MIX_GetMasterGain(MIX_Mixer *mixer);
  * \since This function is available since SDL_mixer 3.0.0.
  *
  * \sa MIX_GetTrackGain
- * \sa MIX_SetMasterGain
+ * \sa MIX_SetMixerGain
  */
 extern SDL_DECLSPEC bool SDLCALL MIX_SetTrackGain(MIX_Track *track, float gain);
 
@@ -2222,7 +2222,7 @@ extern SDL_DECLSPEC bool SDLCALL MIX_SetTrackGain(MIX_Track *track, float gain);
  * \since This function is available since SDL_mixer 3.0.0.
  *
  * \sa MIX_SetTrackGain
- * \sa MIX_GetMasterGain
+ * \sa MIX_GetMixerGain
  */
 extern SDL_DECLSPEC float SDLCALL MIX_GetTrackGain(MIX_Track *track);
 
@@ -2258,7 +2258,7 @@ extern SDL_DECLSPEC float SDLCALL MIX_GetTrackGain(MIX_Track *track);
  *
  * \sa MIX_GetTrackGain
  * \sa MIX_SetTrackGain
- * \sa MIX_SetMasterGain
+ * \sa MIX_SetMixerGain
  * \sa MIX_TagTrack
  */
 extern SDL_DECLSPEC bool SDLCALL MIX_SetTagGain(MIX_Mixer *mixer, const char *tag, float gain);
@@ -2292,15 +2292,15 @@ extern SDL_DECLSPEC bool SDLCALL MIX_SetTagGain(MIX_Mixer *mixer, const char *ta
  *
  * \since This function is available since SDL_mixer 3.0.0.
  *
- * \sa MIX_GetMasterFrequencyRatio
+ * \sa MIX_GetMixerFrequencyRatio
  * \sa MIX_SetTrackFrequencyRatio
  */
-extern SDL_DECLSPEC bool SDLCALL MIX_SetMasterFrequencyRatio(MIX_Mixer *mixer, float ratio);
+extern SDL_DECLSPEC bool SDLCALL MIX_SetMixerFrequencyRatio(MIX_Mixer *mixer, float ratio);
 
 /**
  * Get a mixer's master frequency ratio.
  *
  * This returns the last value set through MIX_SetMasterFrequencyRatio(), or
  * 1.0f if no value has ever been explicitly set.
  *
  * \param mixer the mixer to query.
@@ -2310,10 +2310,10 @@ extern SDL_DECLSPEC bool SDLCALL MIX_SetMasterFrequencyRatio(MIX_Mixer *mixer, f
  *
  * \since This function is available since SDL_mixer 3.0.0.
  *
- * \sa MIX_SetMasterFrequencyRatio
+ * \sa MIX_SetMixerFrequencyRatio
  * \sa MIX_GetTrackFrequencyRatio
  */
-extern SDL_DECLSPEC float SDLCALL MIX_GetMasterFrequencyRatio(MIX_Mixer *mixer);
+extern SDL_DECLSPEC float SDLCALL MIX_GetMixerFrequencyRatio(MIX_Mixer *mixer);
 
 
 /**
@@ -2157,15 +2157,15 @@ extern SDL_DECLSPEC bool SDLCALL MIX_TrackPaused(MIX_Track *track);
  * Get a mixer's master gain control.
  *
- * This returns the last value set through MIX_SetMasterGain(), or 1.0f if no
+ * This returns the last value set through MIX_SetMixerGain(), or 1.0f if no
  * value has ever been explicitly set.
  *
@@ -2292,15 +2292,15 @@ extern SDL_DECLSPEC bool SDLCALL MIX_SetTagGain(MIX_Mixer *mixer, const char *ta
  * Get a mixer's master frequency ratio.
  *
- * This returns the last value set through MIX_SetMasterFrequencyRatio(), or
+ * This returns the last value set through MIX_SetMixerFrequencyRatio(), or
  * 1.0f if no value has ever been explicitly set.
  *